==> owncloud-8.1.0p2.tgz: owncloud/apps/encryption/l10n/es_MX.js <==
OC.L10N.register(
    "encryption",
    {
    "Recovery key successfully enabled" : "Se ha habilitado la recuperación de archivos",
    "Could not enable recovery key. Please check your recovery key password!" : "No se pudo habilitar la clave de recuperación. Por favor compruebe su contraseña.",
    "Recovery key successfully disabled" : "Clave de recuperación deshabilitada",
    "Could not disable recovery key. Please check your recovery key password!" : "No se pudo deshabilitar la clave de recuperación. Por favor compruebe su contraseña!",
    "Password successfully changed." : "Su contraseña ha sido cambiada",
    "Could not change the password. Maybe the old password was not correct." : "No se pudo cambiar la contraseña. Compruebe que la contraseña actual sea correcta.",
    "Private key password successfully updated." : "Contraseña de clave privada actualizada con éxito.",
    "Invalid private key for Encryption App. Please update your private key password in your personal settings to recover access to your encrypted files." : "La clave privada no es válida para la aplicación de cifrado. Por favor, actualiza la contraseña de tu clave privada en tus ajustes personales para recuperar el acceso a tus archivos cifrados.",
    "Encryption App is enabled but your keys are not initialized, please log-out and log-in again" : "La aplicación de crifrado está habilitada pero tus claves no han sido inicializadas, por favor, cierra la sesión y vuelva a iniciarla de nuevo.",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "No fue posible descifrar este archivo, probablemente se trate de un archivo compartido. Solicite al propietario del mismo que vuelva a compartirlo con usted.",
    "Recovery key password" : "Contraseña de clave de recuperación",
    "Change recovery key password:" : "Cambiar la contraseña de la clave de recuperación",
    "Change Password" : "Cambiar contraseña",
    " If you don't remember your old password you can ask your administrator to recover your files." : "Si no recuerda su antigua contraseña puede pedir a su administrador que le recupere sus archivos.",
    "Old log-in password" : "Contraseña de acceso antigua",
    "Current log-in password" : "Contraseña de acceso actual",
    "Update Private Key Password" : "Actualizar Contraseña de Clave Privada",
    "Enable password recovery:" : "Habilitar la recuperación de contraseña:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Habilitar esta opción le permitirá volver a tener acceso a sus archivos cifrados en caso de pérdida de contraseña",
    "Enabled" : "Habilitar",
    "Disabled" : "Deshabilitado"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.7.tgz: owncloud/apps/encryption/l10n/es_MX.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Falta contraseña para llave de recuperación",
    "Please repeat the recovery key password" : "Por favor repite la contraseña de la llave de recuperación",
    "Repeated recovery key password does not match the provided recovery key password" : "La contraseña repetida para la llave de recuperación no es igual la contraseña especificada para la llave de recuperación",
    "Recovery key successfully enabled" : "Se ha habilitado la recuperación de archivos",
    "Could not enable recovery key. Please check your recovery key password!" : "No se pudo habilitar la clave de recuperación. Por favor compruebe su contraseña.",
    "Recovery key successfully disabled" : "Clave de recuperación deshabilitada",
    "Could not disable recovery key. Please check your recovery key password!" : "No se pudo deshabilitar la clave de recuperación. Por favor compruebe su contraseña!",
    "Password successfully changed." : "Su contraseña ha sido cambiada",
    "Could not change the password. Maybe the old password was not correct." : "No se pudo cambiar la contraseña. Compruebe que la contraseña actual sea correcta.",
    "Private key password successfully updated." : "Contraseña de clave privada actualizada con éxito.",
    "Invalid private key for Encryption App. Please update your private key password in your personal settings to recover access to your encrypted files." : "La clave privada no es válida para la aplicación de cifrado. Por favor, actualiza la contraseña de tu clave privada en tus ajustes personales para recuperar el acceso a tus archivos cifrados.",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "No fue posible descifrar este archivo, probablemente se trate de un archivo compartido. Solicite al propietario del mismo que vuelva a compartirlo con usted.",
    "The share will expire on %s." : "El objeto dejará de ser compartido el %s.",
    "Cheers!" : "¡Saludos!",
    "Encryption App is enabled but your keys are not initialized, please log-out and log-in again" : "La aplicación de crifrado está habilitada pero tus claves no han sido inicializadas, por favor, cierra la sesión y vuelva a iniciarla de nuevo.",
    "Recovery key password" : "Contraseña de clave de recuperación",
    "Change recovery key password:" : "Cambiar la contraseña de la clave de recuperación",
    "Change Password" : "Cambiar contraseña",
    " If you don't remember your old password you can ask your administrator to recover your files." : "Si no recuerda su antigua contraseña puede pedir a su administrador que le recupere sus archivos.",
    "Old log-in password" : "Contraseña de acceso antigua",
    "Current log-in password" : "Contraseña de acceso actual",
    "Update Private Key Password" : "Actualizar Contraseña de Clave Privada",
    "Enable password recovery:" : "Habilitar la recuperación de contraseña:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Habilitar esta opción le permitirá volver a tener acceso a sus archivos cifrados en caso de pérdida de contraseña",
    "Enabled" : "Habilitar",
    "Disabled" : "Deshabilitado"
},
"nplurals=2; plural=(n != 1);");
